@@ -259,6 +259,14 @@ py_dump_plugin (void)
   PyObject *fn;
   PyObject *r;
 
+#ifdef PY_VERSION
+  printf ("python_version=%s\n", PY_VERSION);
+#endif
+
+#ifdef PYTHON_ABI_VERSION
+  printf ("python_pep_384_abi_version=%d\n", PYTHON_ABI_VERSION);
+#endif
+
   if (script && callback_defined ("dump_plugin", &fn)) {
     PyErr_Clear ();
 
@@ -279,7 +287,8 @@ py_config (const char *key, const char *value)
   if (!script) {
     /* The first parameter MUST be "script". */
     if (strcmp (key, "script") != 0) {
-      nbdkit_error ("the first parameter must be script=/path/to/python/script.py");
+      nbdkit_error ("the first parameter must be "
+                    "script=/path/to/python/script.py");
       return -1;
     }
     script = value;
@@ -314,7 +323,10 @@ py_config (const char *key, const char *value)
     if (!callback_defined ("open", NULL) ||
         !callback_defined ("get_size", NULL) ||
         !callback_defined ("pread", NULL)) {
-      nbdkit_error ("%s: one of the required callbacks 'open', 'get_size' or 'pread' is not defined by this Python script.  nbdkit requires these callbacks.", script);
+      nbdkit_error ("%s: one of the required callbacks "
+                    "'open', 'get_size' or 'pread' "
+                    "is not defined by this Python script.  "
+                    "nbdkit requires these callbacks.", script);
       return -1;
     }
   }
